@@ -6,7 +6,7 @@
 # Author: jianglin
 # Email: mail@honmaple.com
 # Created: 2018-02-26 11:44:43 (CST)
-# Last Update: Tuesday 2020-08-18 01:59:04 (CST)
+# Last Update: Tuesday 2020-08-18 02:14:37 (CST)
 # Description:
 # ********************************************************************************
 import re
@@ -36,7 +36,7 @@ LIST_STATUS_REGEXP = re.compile(r"\[( |X|-)\]\s")
 LIST_LEVEL_REGEXP = re.compile(r"(\s*)(.+)$")
 
 HEADLINE_REGEXP = re.compile(
-    r"^(\*+)(?:\s+(.+?))?(?:\s+\[#(.+)\])?\s+(.+?)(?:\s+:(.+):)?$")
+    r"^(\*+)(?:\s+(.+?))?(?:\s+\[#(.+)\])?(\s+.*?)(?:\s+:(.+):)?$")
 KEYWORD_REGEXP = re.compile(r"^(\s*)#\+([^:]+):(\s+(.*)|$)")
 COMMENT_REGEXP = re.compile(r"^(\s*)#(.*)")
 ATTRIBUTE_REGEXP = re.compile(r"(?:^|\s+)(:[-\w]+)\s+(.*)$")
@@ -284,15 +284,15 @@ class Headline(Parser):
             return
 
         stars = len(match[1])
-        keyword = match[2]
-        priority = match[3]
+        keyword = match[2] or ""
+        priority = match[3] or ""
 
         if keyword and not priority:
             if len(keyword) >= 4 and keyword[0:2] == "[#":
                 priority = keyword[2:-1]
                 keyword = ""
 
-        title = keyword + " " + match[4]
+        title = keyword + match[4]
         keyword = ""
 
         return cls(
